==> gowiz_country-0.0.1.crate: gowiz_country-0.0.1/src/regions.rs <==
use crate::country::{Country, NUMBER_OF_COUNTRIES};

pub const ALL_COUNTRIES: [Country; NUMBER_OF_COUNTRIES as usize] = [
    Country::ABW,
    Country::AFG,
    Country::AGO,
    Country::AIA,
    Country::ALA,
    Country::ALB,
    Country::AND,
    Country::ANT,
    Country::ARE,
    Country::ARG,
    Country::ARM,
    Country::ASM,
    Country::ATA,
    Country::ATF,
    Country::ATG,
    Country::AUS,
    Country::AUT,
    Country::AZE,
    Country::BDI,
    Country::BEL,
    Country::BEN,
    Country::BFA,
    Country::BGD,
    Country::BGR,
    Country::BHR,
    Country::BHS,
    Country::BIH,
    Country::BLM,
    Country::BLR,
    Country::BLZ,
    Country::BMU,
    Country::BOL,
    Country::BRA,
    Country::BRB,
    Country::BRN,
    Country::BTN,
    Country::BVT,
    Country::BWA,
    Country::CAF,
    Country::CAN,
    Country::CCK,
    Country::CHE,
    Country::CHL,
    Country::CHN,
    Country::CIV,
    Country::CMR,
    Country::COD,
    Country::COG,
    Country::COK,
    Country::COL,
    Country::COM,
    Country::CPV,
    Country::CRI,
    Country::CUB,
    Country::CXR,
    Country::CYM,
    Country::CYP,
    Country::CZE,
    Country::DEU,
    Country::DJI,
    Country::DMA,
    Country::DNK,
    Country::DOM,
    Country::DZA,
    Country::ECU,
    Country::EGY,
    Country::ERI,
    Country::ESH,
    Country::ESP,
    Country::EST,
    Country::ETH,
    Country::FIN,
    Country::FJI,
    Country::FLK,
    Country::FRA,
    Country::FRO,
    Country::FM,
    Country::GAB,
    Country::GB,
    Country::GEO,
    Country::GGY,
    Country::GHA,
    Country::GIB,
    Country::GIN,
    Country::GLP,
    Country::GMB,
    Country::GNB,
    Country::GNQ,
    Country::GRC,
    Country::GRD,
    Country::GRL,
    Country::GTM,
    Country::CUF,
    Country::GUM,
    Country::GUY,
    Country::HKG,
    Country::HMD,
    Country::HND,
    Country::HRV,
    Country::HTI,
    Country::HUN,
    Country::IDN,
    Country::IMN,
    Country::IND,
    Country::IOT,
    Country::IRL,
    Country::IRN,
    Country::IRQ,
    Country::ISL,
    Country::ISR,
    Country::ITA,
    Country::JAM,
    Country::JEY,
    Country::JOR,
    Country::JPN,
    Country::KAZ,
    Country::KEN,
    Country::KGZ,
    Country::KHM,
    Country::KIR,
    Country::KNA,
    Country::KOR,
    Country::KWT,
    Country::LAO,
    Country::LBN,
    Country::LBR,
    Country::LBY,
    Country::LCA,
    Country::LIE,
    Country::LKA,
    Country::LSO,
    Country::LTU,
    Country::LUX,
    Country::LVA,
    Country::MAC,
    Country::MAF,
    Country::MAR,
    Country::MCO,
    Country::MDA,
    Country::MDG,
    Country::MDV,
    Country::MEX,
    Country::MHL,
    Country::MKD,
    Country::MLI,
    Country::MLT,
    Country::MMR,
    Country::MNE,
    Country::MNG,
    Country::MNP,
    Country::MOZ,
    Country::MRT,
    Country::MS,
    Country::MTQ,
    Country::MUS,
    Country::MWI,
    Country::MYS,
    Country::MYT,
    Country::NAM,
    Country::NCL,
    Country::NER,
    Country::NFK,
    Country::NGA,
    Country::NIC,
    Country::NIU,
    Country::NLD,
    Country::NOR,
    Country::NPL,
    Country::NRU,
    Country::NZL,
    Country::OMN,
    Country::PAK,
    Country::PAN,
    Country::PCN,
    Country::PER,
    Country::PHL,
    Country::PLW,
    Country::PNG,
    Country::POL,
    Country::PRI,
    Country::PRK,
    Country::PRT,
    Country::PRY,
    Country::PSE,
    Country::PYF,
    Country::QAT,
    Country::REU,
    Country::ROU,
    Country::RUS,
    Country::RWA,
    Country::SAU,
    Country::SDN,
    Country::SEN,
    Country::SGP,
    Country::SGS,
    Country::SHN,
    Country::SJM,
    Country::SLB,
    Country::SLE,
    Country::SLV,
    Country::SMR,
    Country::SOM,
    Country::SPM,
    Country::SRB,
    Country::STP,
    Country::SUR,
    Country::SVK,
    Country::SVN,
    Country::SWE,
    Country::SWZ,
    Country::SYC,
    Country::SYR,
    Country::TCA,
    Country::TCD,
    Country::TGO,
    Country::THA,
    Country::TJK,
    Country::TKL,
    Country::TKM,
    Country::TLS,
    Country::TON,
    Country::TTO,
    Country::TUN,
    Country::TUR,
    Country::TUV,
    Country::TWN,
    Country::TZA,
    Country::UGA,
    Country::UKR,
    Country::UMI,
    Country::URY,
    Country::USA,
    Country::UZB,
    Country::VAT,
    Country::VCT,
    Country::VEN,
    Country::VGB,
    Country::VIR,
    Country::VNM,
    Country::VUT,
    Country::WLF,
    Country::WSM,
    Country::YEM,
    Country::ZAF,
    Country::ZMB,
    Country::ZWE,
];

==> gowiz_country-0.0.2.crate: gowiz_country-0.0.2/src/regions.rs <==
use crate::models::country::{Country, NUMBER_OF_COUNTRIES};

pub const ALL_COUNTRIES: [Country; NUMBER_OF_COUNTRIES as usize] = [
    Country::ABW,
    Country::AFG,
    Country::AGO,
    Country::AIA,
    Country::ALA,
    Country::ALB,
    Country::AND,
    Country::ANT,
    Country::ARE,
    Country::ARG,
    Country::ARM,
    Country::ASM,
    Country::ATA,
    Country::ATF,
    Country::ATG,
    Country::AUS,
    Country::AUT,
    Country::AZE,
    Country::BDI,
    Country::BEL,
    Country::BEN,
    Country::BES,
    Country::BFA,
    Country::BGD,
    Country::BGR,
    Country::BHR,
    Country::BHS,
    Country::BIH,
    Country::BLM,
    Country::BLR,
    Country::BLZ,
    Country::BMU,
    Country::BOL,
    Country::BRA,
    Country::BRB,
    Country::BRN,
    Country::BTN,
    Country::BVT,
    Country::BWA,
    Country::CAF,
    Country::CAN,
    Country::CCK,
    Country::CHE,
    Country::CHL,
    Country::CHN,
    Country::CIV,
    Country::CMR,
    Country::COD,
    Country::COG,
    Country::COK,
    Country::COL,
    Country::COM,
    Country::CPV,
    Country::CRI,
    Country::CUB,
    Country::CUW,
    Country::CXR,
    Country::CYM,
    Country::CYP,
    Country::CZE,
    Country::DEU,
    Country::DJI,
    Country::DMA,
    Country::DNK,
    Country::DOM,
    Country::DZA,
    Country::ECU,
    Country::EGY,
    Country::ERI,
    Country::ESH,
    Country::ESP,
    Country::EST,
    Country::ETH,
    Country::FIN,
    Country::FJI,
    Country::FLK,
    Country::FRA,
    Country::FRO,
    Country::FSM,
    Country::GAB,
    Country::GBR,
    Country::GEO,
    Country::GGY,
    Country::GHA,
    Country::GIB,
    Country::GIN,
    Country::GLP,
    Country::GMB,
    Country::GNB,
    Country::GNQ,
    Country::GRC,
    Country::GRD,
    Country::GRL,
    Country::GTM,
    Country::GUF,
    Country::GUM,
    Country::GUY,
    Country::HKG,
    Country::HMD,
    Country::HND,
    Country::HRV,
    Country::HTI,
    Country::HUN,
    Country::IDN,
    Country::IMN,
    Country::IND,
    Country::IOT,
    Country::IRL,
    Country::IRN,
    Country::IRQ,
    Country::ISL,
    Country::ISR,
    Country::ITA,
    Country::JAM,
    Country::JEY,
    Country::JOR,
    Country::JPN,
    Country::KAZ,
    Country::KEN,
    Country::KGZ,
    Country::KHM,
    Country::KIR,
    Country::KNA,
    Country::KOR,
    Country::KWT,
    Country::LAO,
    Country::LBN,
    Country::LBR,
    Country::LBY,
    Country::LCA,
    Country::LIE,
    Country::LKA,
    Country::LSO,
    Country::LTU,
    Country::LUX,
    Country::LVA,
    Country::MAC,
    Country::MAF,
    Country::MAR,
    Country::MCO,
    Country::MDA,
    Country::MDG,
    Country::MDV,
    Country::MEX,
    Country::MHL,
    Country::MID,
    Country::MKD,
    Country::MLI,
    Country::MLT,
    Country::MMR,
    Country::MNE,
    Country::MNG,
    Country::MNP,
    Country::MOZ,
    Country::MRT,
    Country::MSR,
    Country::MTQ,
    Country::MUS,
    Country::MWI,
    Country::MYS,
    Country::MYT,
    Country::NAM,
    Country::NCL,
    Country::NER,
    Country::NFK,
    Country::NGA,
    Country::NIC,
    Country::NIU,
    Country::NLD,
    Country::NOR,
    Country::NPL,
    Country::NRU,
    Country::NZL,
    Country::OMN,
    Country::PAK,
    Country::PAN,
    Country::PCN,
    Country::PER,
    Country::PHL,
    Country::PLW,
    Country::PNG,
    Country::POL,
    Country::PRI,
    Country::PRK,
    Country::PRT,
    Country::PRY,
    Country::PSE,
    Country::PYF,
    Country::QAT,
    Country::REU,
    Country::ROU,
    Country::RUS,
    Country::RWA,
    Country::SAU,
    Country::SDN,
    Country::SEN,
    Country::SGP,
    Country::SGS,
    Country::SHN,
    Country::SJM,
    Country::SLB,
    Country::SLE,
    Country::SLV,
    Country::SMR,
    Country::SOM,
    Country::SPM,
    Country::SRB,
    Country::SSD,
    Country::STP,
    Country::SUR,
    Country::SVK,
    Country::SVN,
    Country::SWE,
    Country::SWZ,
    Country::SXM,
    Country::SYC,
    Country::SYR,
    Country::TCA,
    Country::TCD,
    Country::TGO,
    Country::THA,
    Country::TJK,
    Country::TKL,
    Country::TKM,
    Country::TLS,
    Country::TON,
    Country::TTO,
    Country::TUN,
    Country::TUR,
    Country::TUV,
    Country::TWN,
    Country::TZA,
    Country::UGA,
    Country::UKR,
    Country::UMI,
    Country::URY,
    Country::USA,
    Country::UZB,
    Country::VAT,
    Country::VCT,
    Country::VEN,
    Country::VGB,
    Country::VIR,
    Country::VNM,
    Country::VUT,
    Country::WLF,
    Country::WSM,
    Country::YEM,
    Country::ZAF,
    Country::ZMB,
    Country::ZWE,
];
